@@ -14,7 +14,7 @@ where
     MetadataWrapper::<T>::deserialize(ctx.data().clone().into_deserializer()).map_err(render_err)
 }
 
-pub fn deserialize_metadata<'rc, 'de>(ctx: &'rc Context) -> Result<Metadata, RenderError> {
+pub fn deserialize_metadata(ctx: &Context) -> Result<Metadata, RenderError> {
     let data = ctx.data().get("metadata").unwrap().clone();
     Metadata::deserialize(data.into_deserializer()).map_err(render_err)
 }
