@@ -56,7 +56,7 @@ fn path_eval<S: AsRef<str>>(p: S) -> PathBuf {
 }
 
 fn main() {
-    static OPTS: Lazy<Opts> = Lazy::new(|| Opts::parse());
+    static OPTS: Lazy<Opts> = Lazy::new(Opts::parse);
     static IN_FILE: Lazy<PathBuf> = Lazy::new(|| {
         let in_file = path_eval(
             OPTS.deref()
@@ -80,9 +80,9 @@ fn main() {
             .out
             .as_ref()
             .map(path_eval)
-            .unwrap_or_else(|| ROOT_DIR.deref().join("dist").to_path_buf())
+            .unwrap_or_else(|| ROOT_DIR.deref().join("dist"))
     });
-    static WATCH: Lazy<bool> = Lazy::new(|| OPTS.deref().watch.clone());
+    static WATCH: Lazy<bool> = Lazy::new(|| OPTS.deref().watch);
     init(ROOT_DIR.as_path());
     if *WATCH.deref() {
         let (tx, rx) = std::sync::mpsc::channel();
@@ -117,7 +117,7 @@ fn main() {
 
 fn build(in_file: PathBuf, root_dir: PathBuf, out: PathBuf) {
     let index =
-        serde_yaml::from_reader::<_, Index>(fs::File::open(in_file.clone()).unwrap()).unwrap();
+        serde_yaml::from_reader::<_, Index>(fs::File::open(in_file).unwrap()).unwrap();
     let index: OutIndex = index.into();
     let finish = index.build().unwrap();
     fs_extra::dir::remove(out.as_path()).unwrap();
@@ -135,4 +135,17 @@ fn build(in_file: PathBuf, root_dir: PathBuf, out: PathBuf) {
     let mut options = fs_extra::file::CopyOptions::new();
     options.overwrite = true;
     fs_extra::file::copy(root_dir.join(index.style), out.join("style.css"), &options).unwrap();
+    let mut options = fs_extra::dir::DirOptions::new();
+    options.depth = u64::MAX - 1;
+    let contents = fs_extra::dir::get_dir_content2(out.clone(), &options).unwrap();
+    let files = contents
+        .files
+        .into_iter()
+        .map(|x| x[(out.to_str().unwrap().len() + 1)..].to_string())
+        .map(|x| x.replace("\\", "/"))
+        .collect::<Vec<String>>();
+    File::create(out.join("files.json"))
+        .unwrap()
+        .write_all(serde_json::to_string(&files).unwrap().as_bytes())
+        .unwrap();
 }
