@@ -2,6 +2,6 @@ use std::borrow::Cow;
 
 use super::regexs;
 
-pub fn new_line<'a>(s: &'a str) -> Cow<'a, str> {
+pub fn new_line(s: &str) -> Cow<str> {
     regexs::new_line().replace_all(s, "<br>")
 }
\ No newline at end of file
